@@ -1,15 +1,14 @@
 """ResNet50 model for Keras.
 
-# Reference:
-
-- [Deep Residual Learning for Image Recognition](
-    https://arxiv.org/abs/1512.03385) (CVPR 2016 Best Paper Award)
+# Reference
+  - [Deep Residual Learning for Image Recognition](
+      https://arxiv.org/abs/1512.03385) (CVPR 2015)
 """
 
 import h5py
 import inaccel.coral as inaccel
 import keras.utils.data_utils as data_utils
-import keras.engine.training_utils as training_utils
+import keras.utils.generic_utils as generic_utils
 import numpy as np
 import os
 
@@ -109,7 +108,7 @@ class ResNet50:
             ValueError: In case of mismatch between the provided
                 input data and the model's expectations.
         """
-        if batch_size is not None and training_utils.is_generator_or_sequence(x):
+        if batch_size is not None and data_utils.is_generator_or_sequence(x):
             raise ValueError('The `batch_size` argument must not be specified when'
                              ' using a generator or Sequence as an input.')
 
@@ -118,7 +117,7 @@ class ResNet50:
             batch_size = 32
 
         # Case 1: generator-like. Input is Python generator, or Sequence object.
-        if training_utils.is_generator_or_sequence(x):
+        if data_utils.is_generator_or_sequence(x):
             return self.predict_generator(
                 x,
                 steps=steps,
@@ -127,7 +126,7 @@ class ResNet50:
 
         # Case 2: Numpy array-like.
         outputs = []
-        for start, stop in training_utils.make_batches(len(x), batch_size):
+        for start, stop in generic_utils.make_batches(len(x), batch_size):
             outputs.append(self.predict_on_batch(x[start:stop]))
         return np.vstack(outputs)
 
@@ -161,7 +160,7 @@ class ResNet50:
                 data in an invalid format.
         """
         outputs = []
-        use_sequence_api = training_utils.is_sequence(generator)
+        use_sequence_api = isinstance(generator, data_utils.Sequence)
         if steps is None:
             if use_sequence_api:
                 steps = len(generator)
